function Circle = conecircle ( u, th, N)

%CIRC = CONECIRCLE ( U, TH, N)
%
% Return the (3,N)-array that represents the N-point intersection line with 
% the unit sphere of a cone with half-angle TH (radians) around the
% direction vector U. U must be of size (1,3) or (3,1).
%
% That is, the routine can be used to draw colid angles on unit sphere.
%
% 19-Oct-2005 Jm

if nargin ~= 3
    error ('Bad number of parameters');
end
u = u(:)/norm(u);
if length(u) ~= 3
    error ('Parameter 1 must have length 3')
end

% Generate a circle of radius sin(th) around the X-axes in the YZ-plane

t = linspace(0,2*pi, N);
[Y,Z] = pol2cart(t,sin(th));
X = zeros(size(Y));
Circle = [X;Y;Z];       % Each column represents one point of the circle

% Rotate the circle so that it's normal points to the direction of u

[az,el,R] = cart2sph(u(1),u(2),u(3));

RotZ = [cos(az)  -sin(az) 0;
        +sin(az) cos(az) 0;
          0        0     1];
RotY = [cos(el)    0    -sin(el);
          0        1       0;
        +sin(el)    0     cos(el)];

Circle = (RotZ*RotY) * Circle;

% Translate the circle by cos(th) in the the direction of u.

T = kron (ones(1,N),cos(th)*u);

Circle = T + Circle;

%keyboard