function hh = getfigure (Figurename, Paperpos, Width)

% H = GETFIGURE (FIGURENAME, PAPERPOS, WIDTH)
%
% Create a figure window if one does not already exists,
% otherwise just select the named figure.
%
% FIGURENAME Is name  for the figure header.
% WIDTH is width of the figure window on screen in pixels
% PAPERPOS is the figures 'PaperPosition' rectangle (inches)
% The screen window will be scaled to the same aspect ratio.
%
% Figure handle H is returned. 

% 24-Oct-2005 Jm
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin ~= 3
    error ('Bad number of parameters')
end

h = findobj('Tag',Figurename);
if isempty(h)
    h = figure;
    set(h,'Tag',Figurename);
    set(h,'Numbertitle','off');
    colordef(h,'white');
    set(h,'PaperType','A4');
    set(h,'Name',Figurename);
    Height = (Paperpos(4)/Paperpos(3))*Width;
    pos = get(gcf,'position');
    set(h,'Position',[pos(1), pos(2), Width, Height]);
    set(gcf,'paperpos',Paperpos);
else
    figure(h);
end

if nargout > 0
    hh = h;
end    

