function simplebeam

set(0,'defaultaxesfontsize',12);

d2r = pi/180;
r2d = 180/pi;

W(1) = 40*d2r;
n(1) = log10 (0.5) / log10 (cos((W(1)/2)/2));
G0(1) = (n+2)/2;

G0(2) = 10
n(2) = 2*G0(2)-2
W(2) = 4 * acos ( (0.5)^(1/n(2)) );

G0_dB = 10*log10(G0)
Wdeg = W*r2d

% Polar-angle grid

th1 = -90*d2r;
th2 = +90*d2r;
th_step = 0.001*d2r; 
th = th1:th_step:th2;

% Compute the element's directivity (=max power gain) G0, assuming 
% insignificant side-lobes in the cos^ny (theta/2) beam power gain pattern.
% (This is found by requiring that the pattern integrates to 4pi.)

for k = 1:2
    G{k} = G0(k) * cos(th/2) .^ n(k);
    G_dB{k} = 10 * log10 (G{k});
end

getfigure('simplebeam',[0.25 2.5 7 3], 500);

subplot(1,2,1)
    set(gca,'pos',[0.1300    0.200    0.32    0.60])
    plot(th*r2d, G{1}/G0(1),'r--', th*r2d, G{2}/G0(2),'b-')
    set(gca,'xlim',[th1 th2]*r2d)
    xlabel ('\theta (\circ)')
    set(gca,'tickdir','out')
    set(gca,'layer','top')
    set(gca,'TickLength', 2*[0.01 0.025])
    set(gca,'xtick',-90:30:90);
    ylabel ('G/Ge')
    title(sprintf('W = %1.1f\\circ and %1.1f\\circ', W(2)*r2d, W(1)*r2d));


subplot(1,2,2)
    set(gca,'pos',[0.5703    0.200    0.32    0.60])
    plot(th*r2d, G_dB{1},'r--', th*r2d, G_dB{2},'b-')
    set(gca,'ylim',[-30 20])
    set(gca,'xlim',[th1 th2]*r2d)
    set(gca,'tickdir','out')
    set(gca,'TickLength', 2*[0.01 0.025])
    set(gca,'xtick',-90:30:90);
    set(gca,'layer','top')
    ylabel ('G (dBi)')
    xlabel ('\theta (\circ)')
    title (sprintf ('Ge = %1.1f dBi and %1.1f dBi', G0_dB(2), G0_dB(1)));
