function two_element_array

% TWO_ELEMENT_ARRAY
%
% Inspect the gain pattern and directivity of a two-element array.
%
% 26-May-2006 Jm

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% Element spacing in units of wavelength

D = 1.8;        

% Phasing angle

theta0 = 60*D2R;

% =========== end of input section ==========


theta = linspace(-pi/2,pi/2,1000);
ux = sin(theta);

u0x = sin(theta0);

% Power integral

PI = 1 + (sin(2*pi*D)/(2*pi*D)) * cos ( 2 * pi * D * u0x )

% Absolutely normalized gainm and directivity for this steering

G = ( 1 + cos ( 2 * pi * D * ( ux - u0x ) ) ) / PI;

Dty = 2/PI

% Grating directions (increase n interval if needed)

n = -10:10;
ug = u0x + n/D;
K = find (abs(ug) <= 1);
ug = ug(K);
theta_g = asin(ug)*180/pi

% Directivity as function of phasing direction, Dty = 2/PI

Th = linspace (0,pi/2,1000);
U0x = sin(Th);
PI = 1 + (sin(2*pi*D)/(2*pi*D)) * cos ( 2 * pi * D * U0x );
Dty = 2 ./ PI;

% GRAPHICS

getfig ([mfilename '_1']);

    if 0
        h = plot (theta*R2D,G);
        xlabel('polar angle');
        ylabel('Gain');
    end
    h = polar (theta,G);
        set (h,'linewidth',1.5);

    Thg = sprintf ('%1.0f^\\circ ', theta_g);
    T = sprintf ('d / \\lambda = %s; \\theta_0=%s^\\circ, \\theta_g = %s',...
                                     num2str(D),...
                                      num2str(theta0*R2D), ...
                                        Thg);

    title(T);


getfig ([mfilename '_2'])

    h = plot (Th*R2D, Dty);
        set (h,'linewidth',1.5);
        
        xlabel('Elevation');
        ylabel('Directivity');



function y = D2R
%---------------
y = pi/180;

function y = R2D
%---------------
y = 180/pi;
